extern "C" {
#include <tcl.h>
#include <tk.h>
#ifdef USE_PTHREADS
#include <pthread.h>
#endif
}
#include <iostream.h>

#include "tclmidi.h"

#ifdef _WINDOWS
extern "C" {
extern unsigned int FAR PASCAL TkMain();
int *tclDummyMainPtr = (int *)TkMain;
}
#endif

#ifndef TCL_7_3
int
main(int argc, char **argv)
{

	Tk_Main(argc, argv, Tcl_AppInit);
	return (0);
}
#endif

extern "C" int
#ifdef _WINDOWS
FAR PASCAL
#endif
Tcl_AppInit(Tcl_Interp *interp)
{
	Tk_Window main;

	main = Tk_MainWindow(interp);

	if (Tcl_Init(interp) != TCL_OK)
		return (TCL_ERROR);
	if (Tk_Init(interp) != TCL_OK)
		return (TCL_ERROR);
	return (Tclm_Init(interp));
}
